package sample;

import java.io.IOException;
import java.net.*;

import javax.security.auth.login.LoginException;

import com.factset.rt.*; // import the API classes
import com.factset.rt.RT_Consumer.Subscription; // for convenience

public class SimpleExample {
	private RT_Consumer consumer;
	
	private final MessageHandler msgHandler = new MessageHandler() {
		public void onMessage(Subscription sub, RT_Message msg) {
			String msgType = "";
			String bid = "";
			String ask = "";
			
			if (msg.isError()) {
				System.err.println("Error: " + msg.getErrorDescription());
				sub.cancel();
				return;
			}
			
			if (msg.exists(FIDS.MSG_TYPE))
				msgType = msg.getField(FIDS.MSG_TYPE);
			if (msg.exists(FIDS.BID_1))
				bid = msg.getField(FIDS.BID_1);
			if (msg.exists(FIDS.ASK_1))
				ask = msg.getField(FIDS.ASK_1);
			
			System.out.println("Update: " + msgType +
					" Bid: " + bid + " Ask: " + ask);
			
			if (msg.isClosed())
				sub.cancel();
		}
	};

	private void run() {
		String connection = "user:pass@api.df.factset.com";
		consumer = new RT_Consumer(connection);
		// for OTP uncomment the below lines
		/*
		try {
			consumer = new RT_Consumer("api-stage.df.factset.com", "user-serial", "identifier", null, null, "", false); //TODO: update with correct OTP values
		} catch (IOException ex) {
			System.err.println("Error while connecting with OTP e:" + ex);
		}
		*/
		try {
			consumer.connect();
		} catch (UnknownHostException e) {
			System.err.println("Error resolving host from: " + connection);
			return;
		} catch (LoginException e) {
			System.err.println("Incorrect username or password: " + connection);
			return;
		} catch (IOException e) {
			System.err.println("Error connecting to server: " + e.getMessage());
			return;
		}
		
		RT_Request req = new RT_Request("FDS1", "FDS-USA");
		Subscription sub = consumer.request(req, msgHandler);
		System.out.println("Made a request for " + req + " sub: " + sub);
		
		while (true) {
			consumer.dispatch(-1);
		}
	}
	
	public static void main(String[] args) {
		SimpleExample example = new SimpleExample();
		example.run();
	}
}
